[][src]Struct web_glitz::extensions::color_buffer_float::Extension

pub struct Extension { /* fields omitted */ }

Extension object for the [color_buffer_float] extension.

See the [color_buffer_float] module documentation for details.

Implementations

impl Extension[src]

pub fn extend<I>(&self, image: I) -> Extended<I> where
    I: AsAttachment,
    I::Format: FloatRenderable
[src]

Wraps an attachable floating point image in a type that can be attached to a [RenderTargetDescriptor] without causing a type error.

The image's internal format must implement FloatRenderable.

Panics

Panics if the image belongs to a different context than the extension.

pub fn extend_multisample<I>(&self, image: I) -> Extended<I> where
    I: AsMultisampleAttachment,
    I::SampleFormat: FloatRenderable
[src]

Wraps an attachable multisample floating point image in a type that can be attached to a [MultisampleRenderTargetDescriptor] without causing a type error.

The image's internal format must implement FloatRenderable.

Panics

Panics if the image belongs to a different context than the extension.